@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # Stalker a Production Asset Management System
-# Copyright (C) 2009-2013 Erkan Ozgur Yilmaz
+# Copyright (C) 2009-2014 Erkan Ozgur Yilmaz
 #
 # This file is part of Stalker.
 #
@@ -19,7 +19,7 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 from sqlalchemy import Column, Integer, ForeignKey, Float
-from sqlalchemy.orm import validates, reconstructor
+from sqlalchemy.orm import validates
 
 from stalker.models.entity import Entity
 
@@ -31,7 +31,7 @@ logger.setLevel(logging_level)
 
 
 class ImageFormat(Entity):
-    """Common image formats for the :class:`~stalker.models.project.Project`\ s.
+    """Common image formats for the :class:`.Project`\ s.
 
     :param width: The width of the format, it cannot be zero or negative, if a
       float number is given it will be converted to integer
@@ -42,7 +42,7 @@ class ImageFormat(Entity):
     :param pixel_aspect: The pixel aspect ratio of the current ImageFormat
       object, it can not be zero or negative, and if given as an integer it
       will be converted to a float, the default value is 1.0
-    
+
     :param print_resolution: The print resolution of the ImageFormat given as
       DPI (dot-per-inch). It can not be zero or negative
     """
@@ -60,7 +60,7 @@ class ImageFormat(Entity):
     width = Column(
         Integer,
         doc="""The width of this format.
-        
+
         * the width should be set to a positive non-zero integer
         * integers are also accepted but will be converted to float
         * for improper inputs the object will raise an exception.
@@ -104,8 +104,7 @@ class ImageFormat(Entity):
                  height=None,
                  pixel_aspect=1.0,
                  print_resolution=300,
-                 **kwargs
-    ):
+                 **kwargs):
         super(ImageFormat, self).__init__(**kwargs)
 
         self.width = width
@@ -114,31 +113,21 @@ class ImageFormat(Entity):
         self.print_resolution = print_resolution
         # self._device_aspect = 1.0
 
-    # @reconstructor
-    # def __init_on_load__(self):
-    #     """initialized the instance variables when the instance created with
-    #     SQLAlchemy
-    #     """
-    # 
-    #     self._device_aspect = None
-    #     #self._update_device_aspect()
-    # 
-    #     # call supers __init_on_load__
-    #     super(ImageFormat, self).__init_on_load__()
-
     @validates("width")
     def _validate_width(self, key, width):
         """validates the given width
         """
-
         if not isinstance(width, (int, float)):
-            raise TypeError("%s.width should be an instance of int or float "
-                            "not %s" % (self.__class__.__name__,
-                                        width.__class__.__name__))
+            raise TypeError(
+                "%s.width should be an instance of int or float not %s" %
+                (self.__class__.__name__, width.__class__.__name__)
+            )
 
         if width <= 0:
-            raise ValueError("%s.width shouldn't be zero or negative" %
-                             self.__class__.__name__)
+            raise ValueError(
+                "%s.width shouldn't be zero or negative" %
+                self.__class__.__name__
+            )
 
         return int(width)
 
@@ -146,15 +135,17 @@ class ImageFormat(Entity):
     def _validate_height(self, key, height):
         """validates the given height
         """
-
         if not isinstance(height, (int, float)):
-            raise TypeError("%s.height should be an instance of int or float"
-                            "not %s" % (self.__class__.__name__,
-                                        height.__class__.__name__))
+            raise TypeError(
+                "%s.height should be an instance of int or float not %s" %
+                (self.__class__.__name__, height.__class__.__name__)
+            )
 
         if height <= 0:
-            raise ValueError("%s.height shouldn't be zero or negative" %
-                             self.__class__.__name__)
+            raise ValueError(
+                "%s.height shouldn't be zero or negative" %
+                self.__class__.__name__
+            )
 
         return int(height)
 
@@ -164,14 +155,16 @@ class ImageFormat(Entity):
         """
 
         if not isinstance(pixel_aspect, (int, float)):
-            raise TypeError("%s.pixel_aspect should be an instance of int or "
-                            "float not %s" %
-                            (self.__class__.__name__,
-                             pixel_aspect.__class__.__name__))
+            raise TypeError(
+                "%s.pixel_aspect should be an instance of int or float not %s"
+                % (self.__class__.__name__, pixel_aspect.__class__.__name__)
+            )
 
         if pixel_aspect <= 0:
-            raise ValueError("%s.pixel_aspect can not be zero or a negative "
-                             "value" % self.__class__.__name__)
+            raise ValueError(
+                "%s.pixel_aspect can not be zero or a negative value" %
+                self.__class__.__name__
+            )
 
         return float(pixel_aspect)
 
@@ -181,14 +174,17 @@ class ImageFormat(Entity):
         """
 
         if not isinstance(print_resolution, (int, float)):
-            raise TypeError("%s.print_resolution should be an instance of "
-                            "int or float not %s" %
-                            (self.__class__.__name__,
-                             print_resolution.__class__.__name__))
+            raise TypeError(
+                "%s.print_resolution should be an instance of int or float "
+                "not %s" %
+                (self.__class__.__name__, print_resolution.__class__.__name__)
+            )
 
         if print_resolution <= 0:
-            raise ValueError("%s.print_resolution should not be zero or "
-                             "negative" % self.__class__.__name__)
+            raise ValueError(
+                "%s.print_resolution should not be zero or negative" %
+                self.__class__.__name__
+            )
 
         return float(print_resolution)
 
@@ -199,15 +195,13 @@ class ImageFormat(Entity):
         because the device_aspect is calculated from the width/height*pixel
         formula, this property is read-only.
         """
-
         return float(self.width) / float(self.height) * self.pixel_aspect
 
     def __eq__(self, other):
         """the equality operator
         """
-
         return super(ImageFormat, self).__eq__(other) and \
-               isinstance(other, ImageFormat) and \
-               self.width == other.width and \
-               self.height == other.height and \
-               self.pixel_aspect == other.pixel_aspect
+            isinstance(other, ImageFormat) and \
+            self.width == other.width and \
+            self.height == other.height and \
+            self.pixel_aspect == other.pixel_aspect
